#
# spec file for package rst2html5
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# tox for python3 seems to be broken due to too recent pluggy
%bcond_with tests

Name:           rst2html5
Version:        1.9.3
Release:        bp156.3.1
Summary:        RestructuredText to (X)HTML5
License:        MIT
Group:          Development/Languages/Python
Url:            https://marianoguerra.github.io/rst2html5/
Source:         https://files.pythonhosted.org/packages/source/r/rst2html5/rst2html5-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-Genshi >= 0.7
BuildRequires:  python3-Pygments >= 2.0.2
BuildRequires:  python3-beautifulsoup4 >= 4.4
BuildRequires:  python3-docutils >= 0.12
%if %{with tests}
BuildRequires:  python3-tox >= 2.3.1
BuildRequires:  python3-nose >= 1.3.7
%endif
Requires:       python3-Genshi >= 0.7
Requires:       python3-Pygments >= 2.0.2
Requires:       python3-docutils >= 0.12
Requires(post):   update-alternatives
Requires(preun):  update-alternatives
BuildArch:      noarch

%description
rst2html tool generates basic HTML and CSS from Restructured Text. It
provides ways to modify the output with extensions like Nice CSS
(thanks to Twitter's Bootstrap CSS) or online presentations with
deck.js.

%prep
%setup -q

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
%fdupes %{buildroot}%{python3_sitelib}

rm %{buildroot}%{_bindir}/rst2html5.py

# To avoid conflicts with the python3-docutils package
mv %{buildroot}%{_bindir}/rst2html5 %{buildroot}%{_bindir}/rst2html5-rst2html5
ln -s -f %{_sysconfdir}/alternatives/rst2html5 %{buildroot}%{_bindir}/rst2html5

%post
update-alternatives --install %{_bindir}/rst2html5 rst2html5 %{_bindir}/rst2html5-rst2html5 30

%preun
if [ ! -f %{_bindir}/rst2html5-rst2html5 ] ; then
   update-alternatives --remove rst2html5 %{_bindir}/rst2html5-rst2html5
fi

%if %{with tests}
%check
tox
%endif

%files
%defattr(-,root,root,-)
%doc AUTHORS.rst CHANGELOG.rst LICENSE
%{_bindir}/rst2html5
%{_bindir}/rst2html5-rst2html5
%ghost %{_sysconfdir}/alternatives/rst2html5
%{python3_sitelib}/rst2html5_.py
%{python3_sitelib}/__pycache__/rst2html5_.*.pyc
%{python3_sitelib}/modules/
%{python3_sitelib}/rst2html5-%{version}-py*.egg-info

%changelog
* Thu Apr 20 2017 toddrme2178@gmail.com
- Update to 1.9.3
  * Fix setup.py
- Update to 1.9.2
  * Fix conflict with docutils==0.13.1 rst2html5.py
- Update to 1.9.1
  * Fix install_requires in setup.py
  * Update list of authors
- Fix source url.
- Remove upstream-included rst2html5-minimal_dependencies.patch
- Implement update-alternatives to avoid conflict with
  python3-docutils.
* Sat Feb 11 2017 jengelh@inai.de
- Update description
* Tue Feb  7 2017 c.b.bakker@carmenbianca.eu
- Added a patch that uses minimal dependency versions instead of
  exact versions.
  * rst2html5-minimal_dependencies.patch (boo#1010414)
* Fri Dec 23 2016 mpluskal@suse.com
- Update to version 1.9:
  * New directives :code:`stylesheet`, :code:`script` and
    :code:`template` for declaring stylesheets, scripts and
    template inside a restructured text.
* Wed Nov  2 2016 mpluskal@suse.com
- Update to version 1.8.2:
  * CodeBlock directive refactored
- Changes for version 1.8.1:
  * Raw html shouldn't be indented
  * CodeBlock directive also registered as code
- Changes for version 1.8:
  * New directives define, undef, ifdef and ifndef to
    conditionally include (or not) a rst snippet.
- Disable tests as we can't satisfy dependencies
* Wed May  4 2016 mpluskal@suse.com
- Install license, changelog and list of authors
* Sun May  1 2016 mpluskal@suse.com
- Update to 1.7.5
  * fixes deleted blank lines in <table><pre> during Genshi
    rendering
  * Testing does not depend on ordered tag attributes anymore
- Update dependencies
  * add beautifulsoup4 and nose
- Cleanup spec file
- Use only python3
* Tue Apr 14 2015 rneuhauser@suse.cz
- prefer python2 in openSUSE-13.1
* Tue Apr 14 2015 rneuhauser@suse.cz
- prefer python2 in openSUSE-12.3
* Tue Apr  7 2015 rneuhauser@suse.cz
- rst2html5-1.7.3
* Tue Mar 31 2015 rneuhauser@suse.cz
- rst2html5-1.6
